@@ -9,16 +9,20 @@
 # copyright (c) 2017-18, Thiago P. Oliveira                           #
 #                                                                     #
 # First version: 11/10/2017                                           #
-# Last update: 18/06/2018                                             #
+# Last update: 29/07/2019                                             #
 # License: GNU General Public License version 2 (June, 1991) or later #
 #                                                                     #
 #######################################################################
 
-##' @title Internal function to produces a longitudinal concordance correlation plot.
+##' @title Internal Function to Produces a Longitudinal Concordance
+##'   Correlation Plot.
 ##'
-##' @description This is an internally called function used to produces a longitudinal concordance correlation plot from fitted ans sampled values with or not non-parametric confidence intervals.
+##' @description This is an internally called function used to produces
+##'   a longitudinal concordance correlation plot from fitted ans
+##'   sampled values with or not non-parametric confidence intervals.
 ##'
-##' @details returns a inital plot for the longitudinal concordance correlation.
+##' @details returns a inital plot for the longitudinal concordance
+##'   correlation.
 ##'
 ##' @usage NULL
 ##'
@@ -43,13 +47,14 @@ if(ci==FALSE){
       geom_path(data=data_plot, colour=arg$colour, size=arg$size)+
       geom_point(data=data_plot2, aes(y=CCC, x=Time), shape=arg$shape)+
       scale_y_continuous(limits = arg$scale_y_continuous)+
-      ggtitle(paste(levels(model$data$FacA)[2], "vs.", levels(model$data$FacA)[1]))+
+      ggtitle(paste(levels(model$data$method)[2], "vs.",
+                    levels(model$data$method)[1]))+
       labs(x = paste0(arg$xlab))+
       labs(y = paste0(arg$ylab))+
       theme(plot.title = element_text(hjust = 0.5))
-      if(arg$scale_y_continuous[2]==1){
-        Plot<-Plot+geom_hline(yintercept = 1, linetype="dashed")
-      }
+    if(arg$scale_y_continuous[2]==1){
+      Plot<-Plot+geom_hline(yintercept = 1, linetype="dashed")
+    }
     print(Plot)
   } else{
     data_plot<-list(NA)
@@ -66,7 +71,8 @@ if(ci==FALSE){
         geom_line(data=data_plot[[i]], colour=arg$colour, size=arg$size)+
         geom_point(data=data_plot2[[i]], aes(y=CCC, x=Time), shape=arg$shape)+
         scale_y_continuous(limits = arg$scale_y_continuous)+
-        ggtitle(paste(levels(model$data$FacA)[i+1], "vs.", levels(model$data$FacA)[1]))+
+        ggtitle(paste(levels(model$data$method)[i+1], "vs.",
+                      levels(model$data$method)[1]))+
         labs(x = paste0(arg$xlab))+
         labs(y = paste0(arg$ylab))+
         theme(plot.title = element_text(hjust = 0.5))
@@ -89,7 +95,8 @@ if(ci==FALSE){
     }
     }else{
       all_plots <- lapply(1:numPlots, function(x) Plot[[x]])
-      ml <- gridExtra::marrangeGrob(all_plots, nrow = 1, ncol = 1, top = " ")
+      ml <- gridExtra::marrangeGrob(all_plots, nrow = 1, ncol = 1,
+                                    top = " ")
       print(ml)
     }
   }
@@ -111,7 +118,8 @@ if(ldb == 1) {
     geom_ribbon(data=data_plot,aes(ymin=lower_rho,ymax=upper_rho),
                 fill="grey70", alpha=0.3,show.legend = TRUE)+
     scale_y_continuous(limits = arg$scale_y_continuous)+
-    ggtitle(paste(levels(model$data$FacA)[2], "vs.", levels(model$data$FacA)[1]))+
+    ggtitle(paste(levels(model$data$method)[2], "vs.",
+                  levels(model$data$method)[1]))+
     labs(x = paste0(arg$xlab))+
     labs(y = paste0(arg$ylab))+
     theme(plot.title = element_text(hjust = 0.5))
@@ -140,7 +148,8 @@ if(ldb == 1) {
       geom_ribbon(data=data_plot[[i]],aes(ymin=lower_rho,ymax=upper_rho),
                   fill="grey70", alpha=0.3,show.legend = TRUE)+
       scale_y_continuous(limits = arg$scale_y_continuous)+
-      ggtitle(paste(levels(model$data$FacA)[i+1], "vs.", levels(model$data$FacA)[1]))+
+      ggtitle(paste(levels(model$data$method)[i+1], "vs.",
+                    levels(model$data$method)[1]))+
       labs(x = paste0(arg$xlab))+
       labs(y = paste0(arg$ylab))+
       theme(plot.title = element_text(hjust = 0.5))
@@ -163,7 +172,8 @@ if(ldb == 1) {
         }
   }else{
      all_plots <- lapply(1:numPlots, function(x) Plot[[x]])
-     ml <- gridExtra::marrangeGrob(all_plots, nrow = 1, ncol = 1, top = " ")
+     ml <- gridExtra::marrangeGrob(all_plots, nrow = 1, ncol = 1,
+                                   top = " ")
       print(ml)
       }
     }
